@@ -27,7 +27,7 @@ extrp.pi0.slope.gam2=function(n1,n2,y,gam2.interval=c(1e-3,6),eps=1e-5)
     my=mean(y)
     Gmat=matrix(c(1,0,
                  -1,0,
-                  0,1),3,2,by=TRUE)
+                  0,1),3,2,byrow=TRUE)
     hvec=matrix(c(0,-1,eps))
     
     f.obj=function(parm){gam2=parm
@@ -126,7 +126,7 @@ extrp.pi0.both.gam2=function(n1,n2,y,gam2.interval=c(1e-3,6),rate.interval=c(.3,
     my=mean(y)
     Gmat=matrix(c(1,0,
                  -1,0,
-                  0,1),3,2,by=TRUE)
+                  0,1),3,2,byrow=TRUE)
     hvec=matrix(c(0,-1,eps))
     
     f.obj0=function(parm0,parm1){#       rate=parm0
